How To Contribute
=================

Every open source project lives from the generous help by contributors that sacrifice their time and ``ramlfications`` is no different.

To make participation as pleasant as possible, this project adheres to the `Code of Conduct`_ by the Python Software Foundation.

Here are a few hints and rules to get you started:

- Current status of the project (including issues & PRs) can be seen on our `waffle.io`_ page.
- Meaning of GitHub labels:
    - ``help wanted``: Feeling generous with your time? These issues are up for grabs.  Ask any questions in the comments of the issue.
    - ``in progress``: This issue is currently being worked on.
    - ``ready``: Issue/bug has been confirmed, and is available for anyone to work on.
    - ``feature``: Feature/idea to extend ``ramlfications``.
    - ``bug``: A bug or issue within ``ramlfications``.
    - ``no repro``: A filled bug that can not be reproduced (feel free to comment/reopen if you find you are seeing this bug).
    - ``wontfix``: A filled issue deemed not relevant to the project in some way.
    - ``duplicate``: Either duplicate issue or PR.

- Take a look at the :doc:`wishlist` for inspiration.
- Any GitHub issue that is labeled ``ready`` is up for grabs.
- Add yourself to the AUTHORS.rst_ file in an alphabetical fashion.
  Every contribution is valuable and shall be credited.
- If your change is noteworthy, add an entry to the changelog_.
- No contribution is too small; please submit as many fixes for typos and grammar bloopers as you can!
- *Always* add tests and docs for your code.
  This is a hard rule; patches with missing tests or documentation won’t be merged – if a feature is not tested or documented, it doesn’t exist.
- Obey `PEP 8`_ and `PEP 257`_.
- Write `good commit messages`_.

.. note::
   If you have something great but aren’t sure whether it adheres -- or even can adhere -- to the rules above: **please submit a pull request anyway**!

   In the best case, we can mold it into something, in the worst case the pull request gets politely closed.
   There’s absolutely nothing to fear.

Thank you for considering to contribute to ``ramlfications``!


.. _`PEP 8`: http://www.python.org/dev/peps/pep-0008/
.. _`PEP 257`: http://www.python.org/dev/peps/pep-0257/
.. _`good commit messages`: http://tbaggery.com/2008/04/19/a-note-about-git-commit-messages.html
.. _`Code of Conduct`: https://www.python.org/psf/codeofconduct/
.. _changelog: https://github.com/spotify/ramlfications/blob/master/docs/changelog.rst
.. _AUTHORS.rst: https://github.com/spotify/ramlfications/blob/master/AUTHORS.rst
.. _`waffle.io`: https://waffle.io/spotify/ramlfications
